@@ -466,7 +466,20 @@ class Client:
     def dispatch_interaction(self, data):
         app_context = InteractionContext(**data)
 
-        coro = getattr(self, f"{app_context.data['name']}_{app_context.data['type']}", None)
+        # here we have to handle 3 different type of interactions
+        # default interactions have a "name"
+        # custom interactions such as Components have a "custom_id" instead
+        # however custom components may have nested components
+        # therefore for custom components always just use name and _component
+
+        if app_context.data.get("custom_id"):
+            # Fire a coro for a component type interaction
+            coro = getattr(self, f"{app_context.data['custom_id']}_component", None)
+
+        else:
+            # Fire a coro for a regular interaction
+            coro = getattr(self, f"{app_context.data['name']}_{app_context.data['type']}", None)
+
         if coro:
             asyncio.create_task(coro(app_context))
 
@@ -587,8 +600,7 @@ class Client:
         description: Optional[str] = None,
         scope: Optional[Union[int, List[int]]] = None,
         options: Optional[List[Option]] = None,
-        default_permission: Optional[bool] = None,
-        permissions: Optional[List[str]] = None
+        default_permission: Optional[str] = str(1 << 11) # 1 << 11 is SEND_MESSAGES permission.
     ) -> Callable[..., Any]:
         """
         A decorator for registering an application command to the Discord API,
@@ -606,7 +618,7 @@ class Client:
         :param options: The "arguments"/options of an application command. This should bel eft blank if you are not using ``CHAT_INPUT``.
         :type options: typing.Optional[typing.List[interactions.models.command.Option]]
         :param default_permission: The default permission of accessibility for the application command. Defaults to ``True``.
-        :type default_permission: typing.Optional[bool]
+        :type default_permission: typing.Optional[str]
         :return: typing.Callable[..., typing.Any]
         """
 
@@ -623,7 +635,7 @@ class Client:
             # Store the function in the bot
             setattr(self, f"{name}_{type}", coro)
             application_data = {'type': type, 'name': name, 'description': description, 'scope': scope, 
-                    'options': options, 'default_permission': default_permission, 'permissions': permissions}
+                    'options': options, 'default_permission': default_permission}
 
             # We need to verify whether the bot is logged in or not.
             if self.is_ready():
@@ -644,8 +656,7 @@ class Client:
         _type: int = application_data["type"].value if isinstance(application_data["type"], ApplicationCommandType) else application_data["type"]
         _description: str = "" if application_data.get("description") is None else application_data["description"]
         _options: list = [] if application_data.get("options") is None else application_data["options"]
-        _default_permission: bool = True if application_data.get("default_permission") is None else application_data["default_permission"]
-        _permissions: list = [] if application_data['permissions'] is None else application_data['permissions']
+        _default_permission: str = str(1 << 11) if application_data.get("default_permission") is None else application_data["default_permission"]
         _scope: list = []
 
         if isinstance(application_data.get("description"), list):
@@ -654,10 +665,6 @@ class Client:
         else:
             _scope.append(application_data.get("scope"))
 
-        # Double check just so users don't fuck up
-        if len(_permissions) > 0:
-            _default_permission = False
-
         for guild in _scope:
             payload: ApplicationCommand = ApplicationCommand(
                 type=_type,
@@ -667,21 +674,37 @@ class Client:
                 default_permission=_default_permission,
             )
 
-            asyncio.create_task(self._register_application_command_and_permissions(application_id, guild, payload, _permissions))
+            asyncio.create_task(self._register_application_command_and_permissions(application_id, guild, payload))
 
-    async def _register_application_command_and_permissions(self, application_id, guild, payload, permissions):
+    async def _register_application_command_and_permissions(self, application_id: str, guild: str, payload: dict) -> None:
         request = await self.http.create_application_command(
             application_id=application_id, data=payload._json, guild_id=guild
         )
 
-        command_id = request['id']
+    def component(
+        self,
+        *,
+        name: Optional[str] = None,
+    ) -> Callable[..., Any]:
+        """
+        A decorator for registering an application components callback from the Discord API
+        """
 
-        if len(permissions) > 0:
-                data = {"permissions": permissions}
+        if not name:
+            raise Exception("Command must have a name!")
 
-                request = await self.http.edit_application_command_permissions(
-                    application_id=application_id, guild_id=guild, command_id=command_id, data=data
-                )
+        def decorator(coro: Coroutine):
+            if not asyncio.iscoroutinefunction(coro):
+                raise TypeError('event registered must be a coroutine function')
+
+            # Store the function in the bot
+            setattr(self, f"{name}_component", coro)
+                
+            log.debug('%s has successfully been queued as an application component callback', coro.__name__)
+
+            return coro
+
+        return decorator
 
     async def raw_socket_create(self, data: dict) -> None:
         # TODO: doctype what this does
